==> libvisio_0.0.31.orig.tar.bz2: libvisio-0.0.31/src/lib/VSDParagraphList.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* libvisio
 * Version: MPL 1.1 / GPLv2+ / LGPLv2+
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License or as specified alternatively below. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Major Contributor(s):
 * Copyright (C) 2011 Fridrich Strba <fridrich.strba@bluewin.ch>
 * Copyright (C) 2011 Eilidh McAdam <tibbylickle@gmail.com>
 *
 *
 * All Rights Reserved.
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
 * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
 * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
 * instead of those above.
 */

#ifndef __VSDPARAGRAPHLIST_H__
#define __VSDPARAGRAPHLIST_H__

#include <vector>
#include <map>
#include "VSDStyles.h"

namespace libvisio
{

class VSDParagraphListElement;
class VSDCollector;

class VSDParagraphList
{
public:
  VSDParagraphList();
  VSDParagraphList(const VSDParagraphList &paraList);
  ~VSDParagraphList();
  VSDParagraphList &operator=(const VSDParagraphList &paraList);
  void addParaIX(unsigned id, unsigned level, unsigned charCount, const boost::optional<double> &indFirst,
                 const boost::optional<double> &indLeft, const boost::optional<double> &indRight, const boost::optional<double> &spLine,
                 const boost::optional<double> &spBefore, const boost::optional<double> &spAfter, const boost::optional<unsigned char> &align,
                 const boost::optional<unsigned> &flags);
  void addParaIX(unsigned id, unsigned level, const VSDOptionalParaStyle &style);
  unsigned getCharCount(unsigned id) const;
  void setCharCount(unsigned id, unsigned charCount);
  void resetCharCount();
  unsigned getLevel() const;

  void setElementsOrder(const std::vector<unsigned> &m_elementsOrder);
  void handle(VSDCollector *collector) const;
  void clear();
  bool empty() const
  {
    return (m_elements.empty());
  }
private:
  std::map<unsigned, VSDParagraphListElement *> m_elements;
  std::vector<unsigned> m_elementsOrder;
};

} // namespace libvisio

#endif // __VSDPARAGRAPHLIST_H__
/* vim:set shiftwidth=2 softtabstop=2 expandtab: */

==> libvisio_0.1.6.orig.tar.bz2: libvisio-0.1.6/src/lib/VSDParagraphList.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * This file is part of the libvisio project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#ifndef __VSDPARAGRAPHLIST_H__
#define __VSDPARAGRAPHLIST_H__

#include <vector>
#include <map>
#include "VSDStyles.h"

namespace libvisio
{

class VSDParagraphListElement;
class VSDCollector;

class VSDParagraphList
{
public:
  VSDParagraphList();
  VSDParagraphList(const VSDParagraphList &paraList);
  ~VSDParagraphList();
  VSDParagraphList &operator=(const VSDParagraphList &paraList);
  void addParaIX(unsigned id, unsigned level, unsigned charCount, const boost::optional<double> &indFirst,
                 const boost::optional<double> &indLeft, const boost::optional<double> &indRight, const boost::optional<double> &spLine,
                 const boost::optional<double> &spBefore, const boost::optional<double> &spAfter, const boost::optional<unsigned char> &align,
                 const boost::optional<unsigned char> &bullet, const boost::optional<VSDName> &bulletStr,
                 const boost::optional<VSDName> &bulletFont, const boost::optional<double> &bulletFontSize,
                 const boost::optional<double> &textPosAfterBullet, const boost::optional<unsigned> &flags);
  void addParaIX(unsigned id, unsigned level, const VSDOptionalParaStyle &style);
  unsigned getCharCount(unsigned id) const;
  void setCharCount(unsigned id, unsigned charCount);
  void resetCharCount();
  unsigned getLevel() const;

  void setElementsOrder(const std::vector<unsigned> &m_elementsOrder);
  void handle(VSDCollector *collector) const;
  void clear();
  bool empty() const
  {
    return (m_elements.empty());
  }
private:
  std::map<unsigned, VSDParagraphListElement *> m_elements;
  std::vector<unsigned> m_elementsOrder;
};

} // namespace libvisio

#endif // __VSDPARAGRAPHLIST_H__
/* vim:set shiftwidth=2 softtabstop=2 expandtab: */
